@@ -23,7 +23,7 @@ def imports() -> str:
         f"from dgraph_orm import {ORM_MODEL_NAME}, Node, GQLException",
         f"from dgraph_orm.ACL.client import DgraphClient",
         "from dgraph_orm.resolver import Params, Resolver",
-        "from typing import Optional, Set, Type, ClassVar, List",
+        "from typing import Optional, Set, Type, ClassVar, List, Union",
     ]
     return "\n".join(lines)
 
@@ -36,6 +36,11 @@ scalar_d = {
     "ID": "str",
     "Int64": "int",
     "DateTime": "datetime",
+    # this is for edgedb
+    "Bigint": "int",  # ? should be float maybe
+    "Decimal": "float",
+    # "JSON": "json",
+    "JSON": "list",  # could also be dict, for now do not use this, just use
 }
 
 
@@ -69,6 +74,13 @@ class NodeConfig(BaseModel):
     # not used in GQL
     node_path: str = None
 
+    # for edgedb until it adds get method
+    unique_fields: T.List[str] = None
+
+    # for CRUD parameter names -> in future, read this from the introspection
+    add_parameter_name: str = "input"
+    update_parameter_name: str = "input"
+
     @classmethod
     def default_from_node_name(cls, node_name: str, url: str) -> NodeConfig:
         return cls(
@@ -136,6 +148,9 @@ class {NODE_CONFIG_NAME}:
     uid_field_name: str = "{self.uid_field_name}"
     
     dgraph_client: DgraphClient = client
+    
+    add_parameter_name: str = "{self.add_parameter_name}"
+    update_parameter_name: str = "{self.update_parameter_name}"
         """
 
         return s
@@ -257,12 +272,18 @@ FilterType = T.TypeVar("FilterType", bound=graphql.GraphQLType)
 
 
 def filter_schema(
-    schema: graphql.GraphQLSchema, gql_cls: T.Type[FilterType]
+    schema: graphql.GraphQLSchema,
+    gql_cls: T.Type[FilterType],
+    extra_classes: T.List[T.Type[FilterType]] = None,
 ) -> T.Dict[str, FilterType]:
+    gql_clses = [gql_cls]
+    if extra_classes:
+        gql_clses = [*gql_clses, *extra_classes]
     filtered_d: T.Dict[str, FilterType] = dict()
     for type_name, type_object in schema.type_map.items():
-        if isinstance(type_object, gql_cls):
-            filtered_d[type_name] = type_object
+        for gql_cls in gql_clses:
+            if isinstance(type_object, gql_cls):
+                filtered_d[type_name] = type_object
     return filtered_d
 
 
@@ -376,6 +397,11 @@ def _build_nodes(
     schema: graphql.GraphQLSchema,
     hydrated: bool = False,
 ) -> str:
+    schema.type_map = {
+        key: value
+        for key, value in schema.type_map.items()
+        if not re.findall(r"[A-Z]\w+_Type", key)
+    }
     type_str_lst: T.List[str] = []
     for type_name, object_type in node_types_d.items():
         node_builder = NodeBuilder(
@@ -448,7 +474,10 @@ class NodeBuilder:
 
     def create_edges_and_fields(self, gql_object: graphql.GraphQLObjectType) -> None:
         for field_name, gql_field in gql_object.fields.items():
-            if isinstance(get_pure_type(gql_field.type), graphql.GraphQLObjectType):
+            pure_type = get_pure_type(gql_field.type)
+            if isinstance(pure_type, graphql.GraphQLObjectType) or isinstance(
+                pure_type, graphql.GraphQLInterfaceType
+            ):
                 self.edges[field_name] = gql_field
             else:
                 self.fields[field_name] = gql_field
@@ -649,22 +678,39 @@ class ResolverBuilder:
 
     def build_get_functions(self) -> str:
         if not self.get_field:
-            return ""
-        params_str = ", ".join(
-            [
-                f"{params_from_gql_arg(arg_name, arg)}"
-                for arg_name, arg in self.get_field.args.items()
-            ]
-        )
-        arg_names = self.get_field.args.keys()
+            if not self.query_field:
+                return ""
+        if self.get_field:
+            params_str = ", ".join(
+                [
+                    f"{params_from_gql_arg(arg_name, arg)}"
+                    for arg_name, arg in self.get_field.args.items()
+                ]
+            )
+        else:
+            params_str = "id: str"
+        if self.get_field:
+            arg_names = self.get_field.args.keys()
+        else:
+            arg_names = ["id"]
         kwargs_str = ", ".join(f'"{arg_name}": {arg_name}' for arg_name in arg_names)
         kwargs_eq_str = ", ".join(f"{arg_name}={arg_name}" for arg_name in arg_names)
         kwargs_d_str = f"{{{kwargs_str}}}"
         print_str = " and ".join([f"{{{arg_name}=}}" for arg_name in arg_names])
-        get = f"""
-async def get(self, {params_str}) -> Optional[{self.node_name}]:
-    return await self._get({kwargs_d_str})
-        """
+        if self.get_field:
+            get = f"""
+    async def get(self, {params_str}) -> Optional[{self.node_name}]:
+        return await self._get({kwargs_d_str})
+            """
+        else:
+            get = f"""
+    async def get(self, {params_str}) -> Optional[{self.node_name}]:
+        self.filter(Filter{self.node_name}(id=FilterID(eq=id)))
+        results = await self.query()
+        if not results:
+            return None
+        return results[0]
+            """
         gerror = f"""
 async def gerror(self, {params_str}) -> {self.node_name}:
     node = await self.get({kwargs_eq_str})
@@ -798,6 +844,15 @@ def build_all(
     schema.type_map = {
         k: schema.type_map[k] for k in sorted(list(schema.type_map.keys()))
     }
+
+    type_map = {}
+    for key, value in schema.type_map.items():
+        if re.findall(r"[A-Z]\w+_Type", key):
+            key = key.replace("_Type", "")
+            value.name = key
+        type_map[key] = value
+    schema.type_map = type_map
+
     enums = build_enums(schema)
     inputs = build_inputs(schema)
     non_input_non_nodes = build_non_input_non_nodes(
@@ -822,7 +877,11 @@ def build_all(
         [f"{name}.update_forward_refs()" for name in input_names]
     )
     update_forward_ref_type_str = "\n".join(
-        [f"{name}.update_forward_refs()" for name in non_input_names]
+        [
+            f"{name}.update_forward_refs()"
+            for name in non_input_names
+            if name not in ["Query", "Mutation"]
+        ]
     )
 
     lines = [
