@@ -8,6 +8,11 @@ from dgraph_orm import GQLException
 from devtools import debug
 from dgraph_orm.ACL.client import DgraphClient
 
+from dgraph_orm.utils.gql import (
+    replace_query_variables_in_query_str,
+    turn_set_remove_filter_ds_to_edgedb_ds,
+)
+
 
 def d_rez(refresh: bool = False, use_stale: bool = False, returns: T.Type = None):
     """The problem w this is it does not do types"""
@@ -159,6 +164,9 @@ class Node(BaseModel):
         update_function_name: str = None
         delete_function_name: str = None
 
+        add_parameter_name: str = None
+        update_parameter_name: str = None
+
         url: str
         uid_field_name: str
 
@@ -396,8 +404,6 @@ class Node(BaseModel):
         }
         resolver = given_resolver or cls.GQL.resolver()
         query_str = resolver.make_update_mutation_str()
-        debug(query_str)
-        debug(variables)
         j = await cls.GQL.dgraph_client.execute(
             query_str=query_str, variables=variables
         )
@@ -423,18 +429,37 @@ class Node(BaseModel):
         given_resolver: T.Optional[ResolverType] = None,
         upsert: bool = None,
         use_one_time: bool = False,
+        use_query_variables: bool = True,  # TODO default for edgedb
     ) -> T.List[NodeModel]:
         resolver = given_resolver or cls.GQL.resolver()
         query_str = resolver.make_add_mutation_str(include_upsert=upsert is not None)
-        variables = {"input": jsonable_encoder(inputs)}
+        variables = {
+            cls.GQL.add_parameter_name: jsonable_encoder(inputs, exclude_unset=True)
+        }
+        if not cls.GQL.payload_node_name:
+            use_query_variables = False
         if upsert is not None:
             variables["upsert"] = upsert
-        j = await cls.GQL.dgraph_client.execute(
-            query_str=query_str, variables=variables, use_one_time=True
-        )
-        node_d_lst = j["data"][f"{cls.GQL.add_function_name}"][
-            cls.GQL.payload_node_name
-        ]
+        # print(f"{variables=}, {query_str=}")
+        if not use_query_variables:
+            better_query_str = replace_query_variables_in_query_str(
+                query_str=query_str, query_variables=variables
+            )
+            # print(f"{better_query_str=}")
+            j = await cls.GQL.dgraph_client.execute(
+                query_str=better_query_str, use_one_time=use_one_time
+            )
+        else:
+            j = await cls.GQL.dgraph_client.execute(
+                query_str=query_str, variables=variables, use_one_time=use_one_time
+            )
+        inner_response = j["data"][f"{cls.GQL.add_function_name}"]
+        if type(inner_response) is dict and (
+            node_d_lst := inner_response.get(cls.GQL.payload_node_name)
+        ):
+            node_d_lst = node_d_lst
+        else:
+            node_d_lst = inner_response
         return [resolver.parse_obj_nested(node_d) for node_d in node_d_lst]
 
     @staticmethod
@@ -448,7 +473,7 @@ class Node(BaseModel):
             if node_or_nodes is None:
                 continue
             if type(node_or_nodes) in [set, list, tuple]:
-                val = {n._uid_field_name: n._uid for n in node_or_nodes}
+                val = [{n._uid_field_name: n._uid} for n in node_or_nodes]
             else:
                 node_or_nodes: NodeModel
                 val = {node_or_nodes._uid_field_name: node_or_nodes._uid}
@@ -464,7 +489,7 @@ class Node(BaseModel):
             if isinstance(val, BaseModel):
                 val = val.json()
             if type(val) is dict:
-                val = json.dumps(val)
+                val = json.dumps(jsonable_encoder(val))
             cleaned_set_d[key] = val
         return cleaned_set_d
 
@@ -496,7 +521,10 @@ class Node(BaseModel):
         set_d: GQL_D,
         remove_d: GQL_D,
         print_update_d: bool = False,
+        use_query_variables: bool = True,  # TODO default for edgedb
     ) -> bool:
+        if not self.GQL.payload_node_name:
+            use_query_variables = False
         """In future, use args from actual update func from gql.schema"""
         if not set_d and not remove_d:
             print("NOTHING TO UPDATE!")
@@ -513,12 +541,28 @@ class Node(BaseModel):
 
         resolver = given_resolver or self._used_resolver
         query_str = resolver.make_update_mutation_str()
-        j = await self.GQL.dgraph_client.execute(
-            query_str=query_str, variables=variables
-        )
-        node_d_lst = j["data"][f"{self.GQL.update_function_name}"][
-            self.GQL.payload_node_name
-        ]
+        # print(f"{query_str=}, {variables=}")
+        if not use_query_variables:
+            query_str = resolver.make_update_mutation_str_edgedb()
+            edgedb_variables = turn_set_remove_filter_ds_to_edgedb_ds(variables)
+            # debug(edgedb_variables)
+
+            better_query_str = replace_query_variables_in_query_str(
+                query_str=query_str, query_variables=edgedb_variables
+            )
+            print(f"{better_query_str=}")
+            j = await self.GQL.dgraph_client.execute(query_str=better_query_str)
+        else:
+            j = await self.GQL.dgraph_client.execute(
+                query_str=query_str, variables=variables
+            )
+        inner_response = j["data"][f"{self.GQL.update_function_name}"]
+        if type(inner_response) is dict and (
+            node_d_lst := inner_response.get(self.GQL.payload_node_name)
+        ):
+            node_d_lst = node_d_lst
+        else:
+            node_d_lst = inner_response
         if not node_d_lst:
             # raise Exception("No update was registered!!")
             print("NO UPDATE WAS REGISTERED")
@@ -530,23 +574,45 @@ class Node(BaseModel):
 
         return True
 
-    async def delete(self, given_resolver: ResolverType = None) -> bool:
+    async def delete(
+        self,
+        given_resolver: ResolverType = None,
+        use_query_variables: bool = True,  # TODO default for edgedb
+    ) -> bool:
+        if not self.GQL.payload_node_name:
+            use_query_variables = False
         """In future, use actual GQL.schema"""
         if not self.GQL.delete_function_name:
             raise GQLException(f"No delete function given for {self.GQL.typename}")
         resolver = given_resolver or self._used_resolver
         query_str = resolver.make_delete_mutation_str()
         variables = {"filter": {self._uid_field_name: self._uid}}
-        j = await self.GQL.dgraph_client.execute(
-            query_str=query_str, variables=variables
-        )
-        node_d_lst = j["data"][f"{self.GQL.delete_function_name}"][
-            self.GQL.payload_node_name
-        ]
+        if not self.GQL.payload_node_name:  # edgedb
+            variables = {"filter": {"id": {"eq": self._uid}}}
+        if not use_query_variables:
+            better_query_str = replace_query_variables_in_query_str(
+                query_str=query_str, query_variables=variables
+            )
+            print(f"{better_query_str=}")
+            j = await self.GQL.dgraph_client.execute(query_str=better_query_str)
+        else:
+            j = await self.GQL.dgraph_client.execute(
+                query_str=query_str, variables=variables
+            )
+
+        inner_response = j["data"][f"{self.GQL.delete_function_name}"]
+        if type(inner_response) is dict and (
+            node_d_lst := inner_response.get(self.GQL.payload_node_name)
+        ):
+            node_d_lst = node_d_lst
+        else:
+            node_d_lst = inner_response
         if not node_d_lst:
             # raise Exception("No update was registered!!")
             print("NO DELETE WAS REGISTERED")
             return False
+        if len(node_d_lst) > 1:
+            print("MANY WERE DELETED, NOT JUST ONE!")
         node_d = node_d_lst[0]
         node = resolver.parse_obj_nested(node_d)
         node._deleted = True
@@ -560,6 +626,7 @@ class Node(BaseModel):
         nodes: T.List[NodeModel],
         given_resolver: ResolverType = None,
     ) -> bool:
+        """As of now this will not work with EdgeDB"""
         if not cls.GQL.delete_function_name:
             raise GQLException(f"No delete function given for {cls.GQL.typename}")
         resolver = given_resolver or cls.GQL.resolver()
